@@ -13,12 +13,21 @@ Including another URLconf
     1. Import the include() function: from django.urls import include, path
     2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
 """
-from django.urls import path
+from django.urls import include, path
 from django.http import HttpResponseRedirect
 
+from dbmcenter.core.tasks.master import init_master
+
 def index(request, *args, **kwargs):
+    """
+    重定向到 VUE 前端
+    """
     return HttpResponseRedirect('dbm-center/index.html')
 
+
 urlpatterns = [
-    path('', index, name='index')
+    path('', index, name='index'),
+    path('apis/agents/', include('agents.urls'), name='apis-agents')
 ]
+
+init_master()
\ No newline at end of file
